/*
 * Copyright 2015 aquenos GmbH.
 * All rights reserved.
 * 
 * Please refer to the file NOTICE.txt in the root of the source distribution or
 * in the META-INF directory of the binary archive for licensing information.
 */

package com.aquenos.epics.jackie.common.io;

/**
 * Interface for a component that does timer based processing. This interface
 * provides the method through which a thread that handles timers multiple
 * components can trigger timer processing for a specific components when a
 * timer that it registered expires.
 * 
 * @author Sebastian Marsching
 * 
 * @see CommunicationController
 */
public interface TimerProcessor {

    /**
     * Performs processing of timed events. This method is called every time
     * that a timer it has registered through the
     * {@link CommunicationController#registerTimer(TimerProcessor, long)}
     * method expires. If multiple timer for this processor expire before the
     * calling thread can call this method, it may aggregate those times and
     * only call this method once.
     */
    void processTimer();

}
